[tryton-debian-vcs] tryton-server branch debian updated. debian/3.6.1-1-4-g43cff6f

Mathias Behrle tryton-debian-vcs at alioth.debian.org
Wed Jul 15 14:23:29 UTC 2015


The following commit has been merged in the debian branch:
https://alioth.debian.org/plugins/scmgit/cgi-bin/gitweb.cgi/?p=tryton/tryton-server.git;a=commitdiff;h=debian/3.6.1-1-4-g43cff6f

commit 43cff6fc82ea3eaf8808e18c15ced165444e21f7
Author: Mathias Behrle <mathiasb at m9s.biz>
Date:   Wed Jul 15 14:09:50 2015 +0200

    Releasing debian version 3.6.2-1.
    
    Signed-off-by: Mathias Behrle <mathiasb at m9s.biz>

diff --git a/debian/changelog b/debian/changelog
index b21a298..1aa6c55 100644
--- a/debian/changelog
+++ b/debian/changelog
@@ -1,3 +1,11 @@
+tryton-server (3.6.2-1) unstable; urgency=medium
+
+  * Adapting section naming in gbp.conf to current git-buildpackage.
+  * Enabling tests on sqlite memory database.
+  * Merging upstream version 3.6.2.
+
+ -- Mathias Behrle <mathiasb at m9s.biz>  Wed, 15 Jul 2015 14:09:50 +0200
+
 tryton-server (3.6.1-1) unstable; urgency=medium
 
   * Running internal cron of trytond by default.
commit ed7f306a1587e852617aea1ea1d01b53ecf4130e
Author: Mathias Behrle <mathiasb at m9s.biz>
Date:   Wed Jul 15 14:09:49 2015 +0200

    Merging upstream version 3.6.2.

diff --git a/CHANGELOG b/CHANGELOG
index 5be6883..0a8a464 100644
--- a/CHANGELOG
+++ b/CHANGELOG
@@ -1,3 +1,6 @@
+Version 3.6.2 - 2015-07-13
+* Bug fixes (see mercurial logs for details)
+
 Version 3.6.1 - 2015-05-19
 * Bug fixes (see mercurial logs for details)
 
diff --git a/PKG-INFO b/PKG-INFO
index 3063a3d..6be4fae 100644
--- a/PKG-INFO
+++ b/PKG-INFO
@@ -1,6 +1,6 @@
 Metadata-Version: 1.1
 Name: trytond
-Version: 3.6.1
+Version: 3.6.2
 Summary: Tryton server
 Home-page: http://www.tryton.org/
 Author: Tryton
diff --git a/trytond.egg-info/PKG-INFO b/trytond.egg-info/PKG-INFO
index 3063a3d..6be4fae 100644
--- a/trytond.egg-info/PKG-INFO
+++ b/trytond.egg-info/PKG-INFO
@@ -1,6 +1,6 @@
 Metadata-Version: 1.1
 Name: trytond
-Version: 3.6.1
+Version: 3.6.2
 Summary: Tryton server
 Home-page: http://www.tryton.org/
 Author: Tryton
diff --git a/trytond/__init__.py b/trytond/__init__.py
index 399c9c2..648a1a7 100644
--- a/trytond/__init__.py
+++ b/trytond/__init__.py
@@ -4,7 +4,7 @@ import os
 import time
 from email import charset
 
-__version__ = "3.6.1"
+__version__ = "3.6.2"
 
 os.environ['TZ'] = 'UTC'
 if hasattr(time, 'tzset'):
diff --git a/trytond/backend/mysql/database.py b/trytond/backend/mysql/database.py
index 9f55458..de31da2 100644
--- a/trytond/backend/mysql/database.py
+++ b/trytond/backend/mysql/database.py
@@ -10,6 +10,8 @@ from MySQLdb import OperationalError as DatabaseOperationalError
 import os
 import time
 import tempfile
+import urllib
+
 from sql import Flavor, Expression
 from sql.functions import Extract, Overlay, CharLength
 
@@ -100,7 +102,7 @@ class Database(DatabaseInterface):
         if uri.username:
             args['user'] = uri.username
         if uri.password:
-            args['passwd'] = uri.password
+            args['passwd'] = urllib.unquote_plus(uri.password)
         conn = MySQLdb.connect(**args)
         cursor = Cursor(conn, self.database_name)
         cursor.execute('SET time_zone = `UTC`')
diff --git a/trytond/backend/postgresql/database.py b/trytond/backend/postgresql/database.py
index 4bc1879..6246846 100644
--- a/trytond/backend/postgresql/database.py
+++ b/trytond/backend/postgresql/database.py
@@ -4,6 +4,7 @@ import time
 import logging
 import re
 import os
+import urllib
 if os.name == 'posix':
     import pwd
 from decimal import Decimal
@@ -69,7 +70,8 @@ class Database(DatabaseInterface):
         port = uri.port and "port=%s" % uri.port or ''
         name = "dbname=%s" % self.database_name
         user = uri.username and "user=%s" % uri.username or ''
-        password = uri.password and "password=%s" % uri.password or ''
+        password = ("password=%s" % urllib.unquote_plus(uri.password)
+            if uri.password else '')
         minconn = config.getint('database', 'minconn', default=1)
         maxconn = config.getint('database', 'maxconn', default=64)
         dsn = '%s %s %s %s %s' % (host, port, name, user, password)
diff --git a/trytond/tools/misc.py b/trytond/tools/misc.py
index a590395..1951bd2 100644
--- a/trytond/tools/misc.py
+++ b/trytond/tools/misc.py
@@ -12,6 +12,7 @@ import smtplib
 from array import array
 from itertools import islice
 import types
+import urllib
 
 from sql import Literal
 from sql.operators import Or
@@ -114,7 +115,9 @@ def get_smtp_server():
         smtp_server.starttls()
 
     if uri.username and uri.password:
-        smtp_server.login(uri.username, uri.password)
+        smtp_server.login(
+            urllib.unquote_plus(uri.username),
+            urllib.unquote_plus(uri.password))
 
     return smtp_server
 
diff --git a/trytond/ir/trigger.py b/trytond/ir/trigger.py
index 704400d..23b8a79 100644
--- a/trytond/ir/trigger.py
+++ b/trytond/ir/trigger.py
@@ -77,7 +77,7 @@ class Trigger(ModelSQL, ModelView):
         super(Trigger, cls).__register__(module_name)
 
         # Migration from 3.4:
         # change minimum_delay into timedelta minimu_time_delay
         if table.column_exist('minimum_delay'):
             cursor.execute(*sql_table.select(
                     sql_table.id, sql_table.minimum_delay,
@@ -85,7 +85,7 @@ class Trigger(ModelSQL, ModelView):
             for id_, delay in cursor.fetchall():
                 delay = datetime.timedelta(hours=delay)
                 cursor.execute(*sql_table.update(
-                        [sql_table.minimu_time_delay],
+                        [sql_table.minimum_time_delay],
                         [delay],
                         where=sql_table.id == id_))
             table.drop_column('minimum_delay')
@@ -77,7 +77,7 @@ class Trigger(ModelSQL, ModelView):
 
         # Migration from 3.4:
-        # change minimum_delay into timedelta minimu_time_delay
+        # change minimum_delay into timedelta minimum_time_delay
         if table.column_exist('minimum_delay'):
             cursor.execute(*sql_table.select(
-- 
tryton-server



More information about the tryton-debian-vcs mailing list